Files
haikuports/media-sound/fluidlite/patches/fluidlite-1.0.0.patchset
Jerome Duval 0453dadd76 fluidlite: add recipe for version 1.0.0.
* static lib only.
2016-08-03 20:22:30 +02:00

67 lines
2.4 KiB
Plaintext

From 87b5d31b533b4b717861da44ff8b05278ddff37f Mon Sep 17 00:00:00 2001
From: Jerome Duval <jerome.duval@gmail.com>
Date: Wed, 3 Aug 2016 19:08:44 +0200
Subject: gcc2 patch
diff --git a/src/fluid_synth.c b/src/fluid_synth.c
index aa3bf60..a743750 100644
--- a/src/fluid_synth.c
+++ b/src/fluid_synth.c
@@ -568,7 +568,8 @@ new_fluid_synth(fluid_settings_t *settings)
void
fluid_synth_set_sample_rate(fluid_synth_t* synth, float sample_rate)
{
- for (int i = 0; i < synth->nvoice; i++) {
+ int i;
+ for (i = 0; i < synth->nvoice; i++) {
delete_fluid_voice(synth->voice[i]);
synth->voice[i] = new_fluid_voice(synth->sample_rate);
}
@@ -3061,6 +3062,7 @@ int fluid_synth_tune_notes(fluid_synth_t* synth, int bank, int prog,
int len, int *key, double* pitch, int apply)
{
fluid_tuning_t* old_tuning, *new_tuning;
+ int i;
if(!(synth != NULL)) return FLUID_FAILED; //fluid_return_val_if_fail
if(!(bank >= 0 && bank < 128)) return FLUID_FAILED; //fluid_return_val_if_fail
@@ -3079,7 +3081,7 @@ int fluid_synth_tune_notes(fluid_synth_t* synth, int bank, int prog,
return FLUID_FAILED;
}
- for (int i = 0; i < len; i++) {
+ for (i = 0; i < len; i++) {
fluid_tuning_set_pitch(new_tuning, key[i], pitch[i]);
}
--
2.2.2
From bf9855376cacbf45d9bfe9906c9b6f8359461a42 Mon Sep 17 00:00:00 2001
From: Pete Goodeve <pete.goodeve@computer.org>
Date: Fri, 24 May 2013 19:33:20 -0700
Subject: adjust fluidsynth fine tuning range to match standard
diff --git a/src/fluid_chan.c b/src/fluid_chan.c
index a06bec7..943465d 100644
--- a/src/fluid_chan.c
+++ b/src/fluid_chan.c
@@ -268,9 +268,9 @@ fluid_channel_cc(fluid_channel_t* chan, int num, int value)
fluid_channel_pitch_wheel_sens (chan, value); /* Set bend range in semitones */
/* FIXME - Handle LSB? (Fine bend range in cents) */
break;
- case RPN_CHANNEL_FINE_TUNE: /* Fine tune is 14 bit over 1 semitone (+/- 50 cents, 8192 = center) */
+ case RPN_CHANNEL_FINE_TUNE: /* Fine tune is 14 bit over +/-1 semitone (+/- 100 cents, 8192 = center) */
fluid_synth_set_gen(chan->synth, chan->channum, GEN_FINETUNE,
- (data - 8192) / 8192.0 * 50.0);
+ (data - 8192) / 8192.0 * 100.0);
break;
case RPN_CHANNEL_COARSE_TUNE: /* Coarse tune is 7 bit and in semitones (64 is center) */
fluid_synth_set_gen(chan->synth, chan->channum, GEN_COARSETUNE,
--
2.2.2